==> orchestra-pvm-4.2.1-sources.jar: org/ow2/orchestra/pvm/internal/cmd/FindExecutionCmd.java <==
/*
 * JBoss, Home of Professional Open Source
 * Copyright 2005, JBoss Inc., and individual contributors as indicated
 * by the @authors tag. See the copyright.txt in the distribution for a
 * full listing of individual contributors.
 *
 * This is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as
 * published by the Free Software Foundation; either version 2.1 of
 * the License, or (at your option) any later version.
 *
 * This software is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this software; if not, write to the Free
 * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA, or see the FSF site: http://www.fsf.org.
 */
package org.ow2.orchestra.pvm.internal.cmd;

import org.ow2.orchestra.pvm.Execution;
import org.ow2.orchestra.pvm.PvmException;
import org.ow2.orchestra.pvm.env.Environment;
import org.ow2.orchestra.pvm.session.PvmDbSession;

/**
 * @author Tom Baeyens
 */
public class FindExecutionCmd implements Command<Execution> {

  private static final long serialVersionUID = 1L;

  protected String executionId;
  protected String processDefinitionName;
  protected String executionKey;

  public FindExecutionCmd(String processDefinitionName, String executionKey) {
    if (processDefinitionName == null) {
      throw new PvmException("processDefinitionName is null");
    }
    this.processDefinitionName = processDefinitionName;
    if (executionKey == null) {
      throw new PvmException("executionKey is null");
    }
    this.executionKey = executionKey;
  }

  public FindExecutionCmd(String executionId) {
    if (executionId == null) {
      throw new PvmException("executionId is null");
    }
    this.executionId = executionId;
  }

  public Execution execute(Environment environment) throws Exception {
    PvmDbSession pvmDbSession = environment.get(PvmDbSession.class);
    if (executionId != null) {
      return pvmDbSession.findExecutionById(executionId);
    }
    return pvmDbSession.findExecutionByKey(processDefinitionName, executionKey);
  }
}

==> orchestra-pvm-4.6.2-sources.jar: org/ow2/orchestra/pvm/internal/cmd/FindExecutionCmd.java <==
/*
 * JBoss, Home of Professional Open Source
 * Copyright 2005, JBoss Inc., and individual contributors as indicated
 * by the @authors tag. See the copyright.txt in the distribution for a
 * full listing of individual contributors.
 *
 * This is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as
 * published by the Free Software Foundation; either version 2.1 of
 * the License, or (at your option) any later version.
 *
 * This software is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this software; if not, write to the Free
 * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA, or see the FSF site: http://www.fsf.org.
 */
package org.ow2.orchestra.pvm.internal.cmd;

import org.ow2.orchestra.pvm.Execution;
import org.ow2.orchestra.pvm.PvmException;
import org.ow2.orchestra.pvm.env.Environment;
import org.ow2.orchestra.pvm.session.PvmDbSession;

/**
 * @author Tom Baeyens
 */
public class FindExecutionCmd implements Command<Execution> {

  private static final long serialVersionUID = 1L;

  protected String executionId;
  protected String processDefinitionName;
  protected String executionKey;

  public FindExecutionCmd(final String processDefinitionName, final String executionKey) {
    if (processDefinitionName == null) {
      throw new PvmException("processDefinitionName is null");
    }
    this.processDefinitionName = processDefinitionName;
    if (executionKey == null) {
      throw new PvmException("executionKey is null");
    }
    this.executionKey = executionKey;
  }

  public FindExecutionCmd(final String executionId) {
    if (executionId == null) {
      throw new PvmException("executionId is null");
    }
    this.executionId = executionId;
  }

  public Execution execute(final Environment environment) {
    final PvmDbSession pvmDbSession = environment.get(PvmDbSession.class);
    if (this.executionId != null) {
      return pvmDbSession.findExecutionById(this.executionId);
    }
    return pvmDbSession.findExecutionByKey(this.processDefinitionName, this.executionKey);
  }
}
